Index: uspace/drv/char/ns8250/ns8250.c
===================================================================
--- uspace/drv/char/ns8250/ns8250.c	(revision 128c78b842343a9ece0922104cf36feb7da16be9)
+++ uspace/drv/char/ns8250/ns8250.c	(revision 765678f460ba0db4d0ba6b052f01e51ab2f3ba90)
@@ -223,10 +223,10 @@
 };
 
-static int ns8250_add_device(ddf_dev_t *dev);
+static int ns8250_dev_add(ddf_dev_t *dev);
 static int ns8250_dev_remove(ddf_dev_t *dev);
 
 /** The serial port device driver's standard operations. */
 static driver_ops_t ns8250_ops = {
-	.add_device = &ns8250_add_device,
+	.dev_add = &ns8250_dev_add,
 	.dev_remove = &ns8250_dev_remove
 };
@@ -717,5 +717,5 @@
 }
 
 /** The add_device callback method of the serial port driver.
  *
  * Probe and initialize the newly added device.
@@ -723,5 +723,5 @@
  * @param dev		The serial port device.
  */
-static int ns8250_add_device(ddf_dev_t *dev)
+static int ns8250_dev_add(ddf_dev_t *dev)
 {
 	ns8250_t *ns = NULL;
@@ -730,5 +730,5 @@
 	int rc;
 	
-	ddf_msg(LVL_DEBUG, "ns8250_add_device %s (handle = %d)",
+	ddf_msg(LVL_DEBUG, "ns8250_dev_add %s (handle = %d)",
 	    dev->name, (int) dev->handle);
 	
@@ -717,5 +717,5 @@
 }
 
-/** The add_device callback method of the serial port driver.
+/** The dev_add callback method of the serial port driver.
  *
  * Probe and initialize the newly added device.
